@@ -15,13 +15,28 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include <crl/common/crl_common_utils.h>
 
 namespace crl {
+namespace details {
 
-inline void init_main_queue(queue_processor processor) {
+extern main_queue_wrapper _main_wrapper;
+
+struct MainQueueWrapper {
+	static inline void Invoke(void (*callable)(void*), void *argument) {
+		_main_wrapper(callable, argument);
+	}
+};
+
+} // namespace details
+
+inline void init_main_queue(main_queue_processor processor) {
+}
+
+inline void wrap_main_queue(main_queue_wrapper wrapper) {
+	details::_main_wrapper = wrapper;
 }
 
 template <typename Callable>
 inline void on_main(Callable &&callable) {
-	return details::on_queue_invoke(
+	return details::on_queue_invoke<details::MainQueueWrapper>(
 		details::main_queue_dispatch(),
 		details::on_queue_async,
 		std::forward<Callable>(callable));
@@ -29,7 +44,7 @@ inline void on_main(Callable &&callable) {
 
 template <typename Callable>
 inline void on_main_sync(Callable &&callable) {
-	return details::on_queue_sync(
+	return details::on_queue_invoke<details::MainQueueWrapper>(
 		details::main_queue_dispatch(),
 		details::on_queue_sync,
 		std::forward<Callable>(callable));
